sheepdog Package
================

:mod:`sheepdog` Package
-----------------------

.. automodule:: sheepdog
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    sheepdog.dog
    sheepdog.sheep

